@@ -1,4 +1,4 @@
-from . import call
+from .call import call
 
 
 def _github(**kwargs):
@@ -6,12 +6,12 @@ def _github(**kwargs):
 
 
 def create_repo(repo):
-    return _github(root="orgs", path="repos", method="POST", body={
-        "name": repo,
-        "private": True,
-        "has_issues": False,
-        "has_wiki": False,
-    })
+    return _github(
+        root="orgs",
+        path="repos",
+        method="POST",
+        body={"name": repo, "private": True, "has_issues": False, "has_wiki": False,},
+    )
 
 
 def delete_repo(repo):
@@ -27,7 +27,7 @@ def create_ref(repo, refname, sha):
         root="repos",
         path=f"{repo}/git/refs",
         method="POST",
-        body={"ref": f"refs/heads/{refname}", "sha": sha}
+        body={"ref": f"refs/heads/{refname}", "sha": sha},
     )
 
 
@@ -36,11 +36,7 @@ def create_merge(repo, base, head, message):
         root="repos",
         path=f"{repo}/merges",
         method="POST",
-        body={
-            "base": base,
-            "head": head,
-            "commit_message": message
-        }
+        body={"base": base, "head": head, "commit_message": message},
     )
 
 
@@ -49,11 +45,7 @@ def update_contents(repo, filename, content, branch, message):
         root="repos",
         path=f"{repo}/contents/{filename}",
         method="PUT",
-        body={
-            "message": message,
-            "branch": branch,
-            "content": content,
-        }
+        body={"message": message, "branch": branch, "content": content,},
     )
 
 
@@ -62,8 +54,5 @@ def delete_contents(repo, filename, branch, message):
         root="repos",
         path=f"{repo}/contents/{filename}",
         method="DELETE",
-        body={
-            "message": message,
-            "branch": branch,
-        }
+        body={"message": message, "branch": branch,},
     )
